表单提示验证 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Form Wizard and Validation

#### Wizard Inside a Modal Box

#### New Item Wizard

Validation

- 1 Validation states
- 2 Alerts
- 3 Payment Info
- 4 Other Info

### Enter the following information

Input with warning
Warning tip help!
Input with error
Error tip help!
Input with success
Success tip help!
Input with info
Info tip help!
Input with error
Error tip help!
Email Address:
Password:
Confirm Password:
Company Name:
Phone Number:
Company URL:
Subscribe to
Latest news and announcements
Product offers and discounts
Gender
Male
Female
State
Platform
Comment
I accept the policy
Well done! You successfully read this important alert message.
Oh snap! Change a few things up and try submitting again.
Warning! Best check yo self, you're not looking too good.
Heads up! This alert needs your attention, but it's not super important.

### This is step 3

### Congrats!

Your product is ready to ship! Click finish to continue!

- 1 Validation states
- 2 Alerts
- 3 Payment Info
- 4 Other Info

#### Step 1

#### Step 2

#### Step 3

#### Step 4

Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container